summaryrefslogtreecommitdiffstats
path: root/src/H5FDsec2.c
diff options
context:
space:
mode:
authorDana Robinson <derobins@hdfgroup.org>2020-05-28 21:33:01 (GMT)
committerDana Robinson <derobins@hdfgroup.org>2020-05-28 21:33:01 (GMT)
commitfa9ea3b127abb5a060b28902560010173bfdbcd0 (patch)
tree941e98fffa2333c573978e1d740775314ae9981a /src/H5FDsec2.c
parentc433d3fb498e0851f7dcc86e758f07e3b69d2dad (diff)
parenta67f73add8e9d8d40b71ad59434c00a606f9bec8 (diff)
downloadhdf5-fa9ea3b127abb5a060b28902560010173bfdbcd0.zip
hdf5-fa9ea3b127abb5a060b28902560010173bfdbcd0.tar.gz
hdf5-fa9ea3b127abb5a060b28902560010173bfdbcd0.tar.bz2
Merge pull request #2613 in HDFFV/hdf5 from ~DEROBINS/hdf5_der:1_10_normalization to hdf5_1_10
* commit 'a67f73add8e9d8d40b71ad59434c00a606f9bec8': Normalization with develop of the VFDs and H5F package.
Diffstat (limited to 'src/H5FDsec2.c')
-rw-r--r--src/H5FDsec2.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/H5FDsec2.c b/src/H5FDsec2.c
index b316666..ba4750e 100644
--- a/src/H5FDsec2.c
+++ b/src/H5FDsec2.c
@@ -208,8 +208,8 @@ done:
* Purpose: Initialize this driver by registering the driver with the
* library.
*
* Return: Success: The driver ID for the sec2 driver.
* Failure: Negative
*
* Programmer: Robb Matzke
* Thursday, July 29, 1999
@@ -221,7 +221,7 @@ H5FD_sec2_init(void)
{
hid_t ret_value = H5I_INVALID_HID; /* Return value */
- FUNC_ENTER_NOAPI(FAIL)
+ FUNC_ENTER_NOAPI(H5I_INVALID_HID)
if(H5I_VFL != H5I_get_type(H5FD_SEC2_g))
H5FD_SEC2_g = H5FD_register(&H5FD_sec2_g, sizeof(H5FD_class_t), FALSE);
@@ -208,8 +208,8 @@ done:
* library.
*
- * Return: Success: The driver ID for the sec2 driver.
- * Failure: Negative
+ * Return: Success: The driver ID for the sec2 driver
+ * Failure: H5I_INVALID_HID
*
* Programmer: Robb Matzke